Welcome to pachypy's documentation!
===================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. toctree::
   :maxdepth: 1
   :caption: API reference

   apidoc/pachypy.rst
